==> hvcg_identity_openapi_identity-0.0.1.crate: hvcg_identity_openapi_identity-0.0.1/docs/query_user_api.md <==
# query_user_api

All URIs are relative to *http://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**query-user-by-id**](query_user_api.md#query-user-by-id) | **GET** /query-api/user/{id} | Get user infomation by id
**query-users**](query_user_api.md#query-users) | **GET** /query-api/users/ | Get users infomation


# **query-user-by-id**
> models::User query-user-by-id(ctx, id)
Get user infomation by id

Returns a single user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| The user id | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **query-users**
> models::User query-users(ctx, optional)
Get users infomation

Returns a single user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
 **optional** | **map[string]interface{}** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a map[string]interface{}.

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [****](.md)| The user id | 
 **username** | **String**| The user name | 
 **phone** | **String**| The userphone number | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> hvcg_identity_openapi_identity-0.1.1.crate: hvcg_identity_openapi_identity-0.1.1/docs/query_user_api.md <==
# query_user_api

All URIs are relative to *http://dev-sg.portal.hocvienconggiao.com*

Method | HTTP request | Description
------------- | ------------- | -------------
**query-user-by-id**](query_user_api.md#query-user-by-id) | **GET** /query-api/users/{id} | Get user infomation by id
**query-users**](query_user_api.md#query-users) | **GET** /query-api/users | Get users infomation


# **query-user-by-id**
> models::User query-user-by-id(ctx, id)
Get user infomation by id

Returns a single user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
  **id** | [****](.md)| The user id | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **query-users**
> models::User query-users(ctx, optional)
Get users infomation

Returns a single user

### Required Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ctx** | **context.Context** | context containing the authentication | nil if no authentication
 **optional** | **map[string]interface{}** | optional parameters | nil if no parameters

### Optional Parameters
Optional parameters are passed through a map[string]interface{}.

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | [****](.md)| The user id | 
 **username** | **String**| The user name | 
 **phone** | **String**| The userphone number | 

### Return type

[**models::User**](User.md)

### Authorization

[user_auth](../README.md#user_auth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
